//#using_animtree( "panzerIV" );

init( precache )
{
	self.collision_fx_str = "fx/vehicle/vehicle_collision.efx";

	if (precache)
	{
		loadfx("fx/explosions/vehicles/t34_mp_n/burn_smoke.efx");
		loadfx("fx/explosions/vehicles/t34_mp_n/1st_exp_v2.efx");
		loadfx("fx/explosions/vehicles/t34_mp_n/2nd_exp.efx");
		loadfx("fx/map_mp/mp_smoke_vehicle_damage.efx");
		loadfx( self.collision_fx_str );
		loadfx ("fx/smoke/ash_smoke.efx");
		loadfx ("fx/weapon/impacts/impact_smg_metal.efx");
		loadfx ("fx/map_mp/mp_fireplace_fire.efx");

	}
	
	if (self.vehicletype == "t34_mp")
	{
		if(self.model == "xmodel/mp_vehicle_t34")
			self.deathmodel = "xmodel/mp_vehicle_t34_destroyed";
		else
			self.deathmodel = "xmodel/mp_vehicle_t34_destroyed";
		
		if (precache)
			precachevehicle("t34_mp");
	}
	else
	if (self.vehicletype == "shermantank_mp")
	{
		if(self.model == "xmodel/mp_vehicle_sherman")
			self.deathmodel = "xmodel/mp_vehicle_sherman_destroyed";
		else if(self.model == "xmodel/mp_vehicle_sherman_snow")
			self.deathmodel = "xmodel/mp_vehicle_sherman_destroyed_snow";
		else
			self.deathmodel = "xmodel/mp_vehicle_sherman_destroyed";
		
		if (precache)
			precachevehicle("shermantank_mp");
	}
	else
	if (self.vehicletype == "panzeriv_mp")
	{
		if (self.model == "xmodel/mp_vehicle_panzeriv")
			self.deathmodel = "xmodel/mp_vehicle_panzeriv_damaged";
		else if (self.model == "xmodel/mp_vehicle_panzeriv_snow")
			self.deathmodel = "xmodel/mp_vehicle_panzeriv_damaged";
		else
			self.deathmodel = "xmodel/mp_vehicle_panzeriv_damaged";
		
		if (precache)
			precachevehicle("panzeriv_mp");
	}
	else
	if (self.vehicletype == "elefant_mp")
	{
		if (self.model == "xmodel/v_ge_lnd_elefant")
			self.deathmodel = "xmodel/v_ge_lnd_elefant(d)";
		
		if (precache)
			precachevehicle("elefant_mp");
	}
	else
	if (self.vehicletype == "su152_mp")
	{
		if (self.model == "xmodel/v_rs_lnd_su152")
			self.deathmodel = "xmodel/v_rs_lnd_su152_d";
		
		if (precache)
			precachevehicle("su152_mp");
	}
	
	if (!isdefined( self.deathmodel ))
	{
		println("vehicle unknown, check that vehicle type and model are both lowercase");
		return;
	}

	if (precache)
	{
		precachemodel(self.deathmodel);
	}

	// start the collision thinker
	self thread tank_collision_thread();
}

tank_collision_thread()
{
	self endon("death");
	
	self.collision_fx = loadfx( self.collision_fx_str );
	
	while (1)
	{
		self waittill("vehicle_collision", pos, dir );
		
		// spawn the collision fx
		playfx( self.collision_fx, pos, dir );
	}
	
}

tank_damaged_smoke()
{
	self endon ("death");
	
	//this was default smoke, not used as it kills fps badly!
	//smokefx = loadfx("fx/map_mp/mp_smoke_vehicle_damage.efx");
	smoke = loadfx ("fx/smoke/ash_smoke.efx");
	sparks = loadfx ("fx/weapon/impacts/impact_smg_metal.efx");
	fire = loadfx ("fx/map_mp/mp_fireplace_fire.efx");
	
	//define tank health values
	maxhealth = self.health;
	healthrange = 900;
	lightdamage = ((maxhealth) - 300);
	mediumdamage = ((maxhealth) - 500);
	heavydamage = ((maxhealth) - 700);
	deathpoint = ((maxhealth) - 900);
	
	while (1)
	{
		self waittill ("damage");

		//for testing damage hits
		//iprintln("Damage inflicted - Max health was " + maxhealth + " Current health now is " + self.health);
			
			if (self.health <= lightdamage)
			{
				//iprintln("Health is at  ",self.health);
				// it's now sparking
					if (!isDefined( spark_ent ))
					{
						// spawn the spark_ent
						org = self.origin + (0,0,120);
						time = randomfloat(1) + 0.25;
						spark_ent = PlayLoopedFX( sparks, time, org, 2048 );
						// kill it once we're dead
						self thread tank_damaged_smoke_stop( spark_ent );
						self thread updatefxpos(spark_ent);
					}
			}
			if (self.health <= mediumdamage)
			{
				//iprintln("Health is at  ",self.health);
				// it's now smoking
					if (!isDefined( smoke_ent ))
					{
						// spawn the smoke_ent
						org = self.origin + (0,0,120);
						time = randomfloat(1) + 0.35;
						smoke_ent = PlayLoopedFX( smoke, time, org, 2048 );
						// kill it once we're dead
						self thread tank_damaged_smoke_stop( smoke_ent );
						self thread updatefxpos(smoke_ent);
					}
			}
			if (self.health <= heavydamage)
			{
				//iprintln("Health is at  ",self.health);
				// it's now on fire
					if (!isDefined( fire_ent ))
					{
						// spawn the fire_ent
						org = self.origin + (0,0,120);
						time = randomfloat(1) + 0.5;
						fire_ent = PlayLoopedFX( fire, time, org, 2048 );
						// kill it once we're dead
						self thread tank_damaged_smoke_stop( fire_ent );
						self thread updatefxpos(fire_ent);
					}
			}
			
	}
}


updatefxpos(ent)
{
	while(ent)
	{
		// update the position
		ent.origin = self.origin + (0,0,120);
		wait 0.1;
	}
}


tank_damaged_smoke_stop(smoke_ent)
{
	self waittill("death");
	
	smoke_ent delete();
}

tankPlayFXUntilEvent( fxId, eventStr )
{
	// spawn the smoke_ent
	smoke_ent = PlayLoopedFX( fxId, 1, self.origin );
	
	self waittill( eventStr );
	
	smoke_ent delete();
}

tank_death()
{
	self.deathfx    = loadfx ("fx/explosions/vehicles/t34_mp_n/burn_smoke.efx");
	self.explode1fx = loadfx( "fx/explosions/vehicles/t34_mp_n/1st_exp_v2.efx" );
	self.explode2fx = loadfx( "fx/explosions/vehicles/t34_mp_n/2nd_exp.efx" );
	self waittill( "death" );
	
	if (!isdefined(self.deepwater))
	{
		//if (isdefined( self.deathmodel ))
		//	self setmodel( self.deathmodel );

		// 1st explode			
		playfxontag( self.explode1fx, self, "tag_origin" );
		earthquake( 0.25, 3, self.origin, 1050 );
		self thread playLoopSoundOnTag("distantfire");
		self thread tankPlayFXUntilEvent( self.deathfx, "allow_explode" );

		self waittill( "allow_explode" );
		println( "recieved allow_explode death");
	
		self notify ("stop sound distantfire");

		// 2nd explode			
		playfxontag( self.explode2fx, self, "tag_origin" );

		// wait for effects to finish
		wait 0.5;
	
		// this will keep the tank from blocking the radius damage
		self setcontents(0);
			
		radiusDamage ( (self.origin[0],self.origin[1],self.origin[2]+25), 300, 150, 10, self);
	}
	else
	{
		println("water death");
		self waittill( "allow_explode" );
	}
	
	// we currently need to remove it straight away, in case it's sitting in the place of the spawning in tank
	self delete();
}

playLoopSoundOnTag(alias, tag)
{
	org = spawn ("script_origin",(0,0,0));
	if (isdefined (tag))
		org linkto (self, tag, (0,0,0), (0,0,0));
	else
	{
		org.origin = self.origin;
		org.angles = self.angles;
		org linkto (self);
	}
	org playloopsound (alias);
//	println ("playing loop sound ", alias," on entity at origin ", self.origin, " at ORIGIN ", org.origin);
	self waittill ("stop sound " + alias);
	org stoploopsound (alias);
	org delete();
}